Class: Aws::DirectoryServiceData::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::DirectoryServiceData::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-directoryservicedata/client.rb,
sig/client.rbs
Overview
An API client for DirectoryServiceData. To construct a client, you need to configure a :region and :credentials.
client = Aws::DirectoryServiceData::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AddGroupMemberResponseSuccess, _CreateGroupResponseSuccess, _CreateUserResponseSuccess, _DeleteGroupResponseSuccess, _DeleteUserResponseSuccess, _DescribeGroupResponseSuccess, _DescribeUserResponseSuccess, _DisableUserResponseSuccess, _ListGroupMembersResponseSuccess, _ListGroupsForMemberResponseSuccess, _ListGroupsResponseSuccess, _ListUsersResponseSuccess, _RemoveGroupMemberResponseSuccess, _SearchGroupsResponseSuccess, _SearchUsersResponseSuccess, _UpdateGroupResponseSuccess, _UpdateUserResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#add_group_member(params = {}) ⇒ Struct
Adds an existing user, group, or computer as a group member.
-
#create_group(params = {}) ⇒ Types::CreateGroupResult
Creates a new group.
-
#create_user(params = {}) ⇒ Types::CreateUserResult
Creates a new user.
-
#delete_group(params = {}) ⇒ Struct
Deletes a group.
-
#delete_user(params = {}) ⇒ Struct
Deletes a user.
-
#describe_group(params = {}) ⇒ Types::DescribeGroupResult
Returns information about a specific group.
-
#describe_user(params = {}) ⇒ Types::DescribeUserResult
Returns information about a specific user.
-
#disable_user(params = {}) ⇒ Struct
Deactivates an active user account.
-
#list_group_members(params = {}) ⇒ Types::ListGroupMembersResult
Returns member information for the specified group.
-
#list_groups(params = {}) ⇒ Types::ListGroupsResult
Returns group information for the specified directory.
-
#list_groups_for_member(params = {}) ⇒ Types::ListGroupsForMemberResult
Returns group information for the specified member.
-
#list_users(params = {}) ⇒ Types::ListUsersResult
Returns user information for the specified directory.
-
#remove_group_member(params = {}) ⇒ Struct
Removes a member from a group.
-
#search_groups(params = {}) ⇒ Types::SearchGroupsResult
Searches the specified directory for a group.
-
#search_users(params = {}) ⇒ Types::SearchUsersResult
Searches the specified directory for a user.
-
#update_group(params = {}) ⇒ Struct
Updates group information.
-
#update_user(params = {}) ⇒ Struct
Updates user information.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-directoryservicedata/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1778 1779 1780 |
# File 'lib/aws-sdk-directoryservicedata/client.rb', line 1778 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1781 1782 1783 |
# File 'lib/aws-sdk-directoryservicedata/client.rb', line 1781 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#add_group_member(params = {}) ⇒ Struct
Adds an existing user, group, or computer as a group member.
85 |
# File 'sig/client.rbs', line 85
def add_group_member: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 |
# File 'lib/aws-sdk-directoryservicedata/client.rb', line 1751 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::DirectoryServiceData') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-directoryservicedata' context[:gem_version] = '1.27.0' Seahorse::Client::Request.new(handlers, context) end |
#create_group(params = {}) ⇒ Types::CreateGroupResult
Creates a new group.
101 |
# File 'sig/client.rbs', line 101
def create_group: (
|
#create_user(params = {}) ⇒ Types::CreateUserResult
Creates a new user.
118 |
# File 'sig/client.rbs', line 118
def create_user: (
|
#delete_group(params = {}) ⇒ Struct
Deletes a group.
133 |
# File 'sig/client.rbs', line 133
def delete_group: (
|
#delete_user(params = {}) ⇒ Struct
Deletes a user.
144 |
# File 'sig/client.rbs', line 144
def delete_user: (
|
#describe_group(params = {}) ⇒ Types::DescribeGroupResult
Returns information about a specific group.
163 |
# File 'sig/client.rbs', line 163
def describe_group: (
|
#describe_user(params = {}) ⇒ Types::DescribeUserResult
Returns information about a specific user.
186 |
# File 'sig/client.rbs', line 186
def describe_user: (
|
#disable_user(params = {}) ⇒ Struct
Deactivates an active user account. For information about how to enable an inactive user account, see ResetUserPassword in the Directory Service API Reference.
198 |
# File 'sig/client.rbs', line 198
def disable_user: (
|
#list_group_members(params = {}) ⇒ Types::ListGroupMembersResult
Returns member information for the specified group.
This operation supports pagination with the use of the NextToken
request and response parameters. If more results are available, the
ListGroupMembers.NextToken member contains a token that you pass in
the next call to ListGroupMembers. This retrieves the next set of
items.
You can also specify a maximum number of return results with the
MaxResults parameter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
214 |
# File 'sig/client.rbs', line 214
def list_group_members: (
|
#list_groups(params = {}) ⇒ Types::ListGroupsResult
Returns group information for the specified directory.
This operation supports pagination with the use of the NextToken
request and response parameters. If more results are available, the
ListGroups.NextToken member contains a token that you pass in the
next call to ListGroups. This retrieves the next set of items.
You can also specify a maximum number of return results with the
MaxResults parameter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
232 |
# File 'sig/client.rbs', line 232
def list_groups: (
|
#list_groups_for_member(params = {}) ⇒ Types::ListGroupsForMemberResult
Returns group information for the specified member.
This operation supports pagination with the use of the NextToken
request and response parameters. If more results are available, the
ListGroupsForMember.NextToken member contains a token that you pass
in the next call to ListGroupsForMember. This retrieves the next set
of items.
You can also specify a maximum number of return results with the
MaxResults parameter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
249 |
# File 'sig/client.rbs', line 249
def list_groups_for_member: (
|
#list_users(params = {}) ⇒ Types::ListUsersResult
Returns user information for the specified directory.
This operation supports pagination with the use of the NextToken
request and response parameters. If more results are available, the
ListUsers.NextToken member contains a token that you pass in the
next call to ListUsers. This retrieves the next set of items.
You can also specify a maximum number of return results with the
MaxResults parameter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
267 |
# File 'sig/client.rbs', line 267
def list_users: (
|
#remove_group_member(params = {}) ⇒ Struct
Removes a member from a group.
279 |
# File 'sig/client.rbs', line 279
def remove_group_member: (
|
#search_groups(params = {}) ⇒ Types::SearchGroupsResult
Searches the specified directory for a group. You can find groups that
match the SearchString parameter with the value of their attributes
included in the SearchString parameter.
This operation supports pagination with the use of the NextToken
request and response parameters. If more results are available, the
SearchGroups.NextToken member contains a token that you pass in the
next call to SearchGroups. This retrieves the next set of items.
You can also specify a maximum number of return results with the
MaxResults parameter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
296 |
# File 'sig/client.rbs', line 296
def search_groups: (
|
#search_users(params = {}) ⇒ Types::SearchUsersResult
Searches the specified directory for a user. You can find users that
match the SearchString parameter with the value of their attributes
included in the SearchString parameter.
This operation supports pagination with the use of the NextToken
request and response parameters. If more results are available, the
SearchUsers.NextToken member contains a token that you pass in the
next call to SearchUsers. This retrieves the next set of items.
You can also specify a maximum number of return results with the
MaxResults parameter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
314 |
# File 'sig/client.rbs', line 314
def search_users: (
|
#update_group(params = {}) ⇒ Struct
Updates group information.
328 |
# File 'sig/client.rbs', line 328
def update_group: (
|
#update_user(params = {}) ⇒ Struct
Updates user information.
343 |
# File 'sig/client.rbs', line 343
def update_user: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1771 1772 1773 |
# File 'lib/aws-sdk-directoryservicedata/client.rb', line 1771 def waiter_names [] end |