Class: Aws::DirectoryServiceData::Types::DescribeGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-directoryservicedata/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#directory_idString

The Identifier (ID) of the directory associated with the group.

Returns:

  • (String)


488
489
490
491
492
493
494
495
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 488

class DescribeGroupRequest < Struct.new(
  :directory_id,
  :other_attributes,
  :realm,
  :sam_account_name)
  SENSITIVE = []
  include Aws::Structure
end

#other_attributesArray<String>

One or more attributes to be returned for the group. For a list of supported attributes, see [Directory Service Data Attributes].

[1]: docs.aws.amazon.com/directoryservice/latest/admin-guide/ad_data_attributes.html

Returns:

  • (Array<String>)


488
489
490
491
492
493
494
495
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 488

class DescribeGroupRequest < Struct.new(
  :directory_id,
  :other_attributes,
  :realm,
  :sam_account_name)
  SENSITIVE = []
  include Aws::Structure
end

#realmString

The domain name that’s associated with the group.

<note markdown=“1”> This parameter is optional, so you can return groups outside of your Managed Microsoft AD domain. When no value is defined, only your Managed Microsoft AD groups are returned.

This value is case insensitive.

</note>

Returns:

  • (String)


488
489
490
491
492
493
494
495
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 488

class DescribeGroupRequest < Struct.new(
  :directory_id,
  :other_attributes,
  :realm,
  :sam_account_name)
  SENSITIVE = []
  include Aws::Structure
end

#sam_account_nameString

The name of the group.

Returns:

  • (String)


488
489
490
491
492
493
494
495
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 488

class DescribeGroupRequest < Struct.new(
  :directory_id,
  :other_attributes,
  :realm,
  :sam_account_name)
  SENSITIVE = []
  include Aws::Structure
end