Class: Aws::DirectoryServiceData::Types::DescribeGroupResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectoryServiceData::Types::DescribeGroupResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directoryservicedata/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:distinguished_name]
Instance Attribute Summary collapse
-
#directory_id ⇒ String
The identifier (ID) of the directory that’s associated with the group.
-
#distinguished_name ⇒ String
The [distinguished name] of the object.
-
#group_scope ⇒ String
The scope of the AD group.
-
#group_type ⇒ String
The AD group type.
-
#other_attributes ⇒ Hash<String,Types::AttributeValue>
The attribute values that are returned for the attribute names that are included in the request.
-
#realm ⇒ String
The domain name that’s associated with the group.
-
#sam_account_name ⇒ String
The name of the group.
-
#sid ⇒ String
The unique security identifier (SID) of the group.
Instance Attribute Details
#directory_id ⇒ String
The identifier (ID) of the directory that’s associated with the group.
547 548 549 550 551 552 553 554 555 556 557 558 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 547 class DescribeGroupResult < Struct.new( :directory_id, :distinguished_name, :group_scope, :group_type, :other_attributes, :realm, :sam_account_name, :sid) SENSITIVE = [:distinguished_name] include Aws::Structure end |
#distinguished_name ⇒ String
The [distinguished name] of the object.
[1]: learn.microsoft.com/en-us/windows/win32/ad/object-names-and-identities#distinguished-name
547 548 549 550 551 552 553 554 555 556 557 558 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 547 class DescribeGroupResult < Struct.new( :directory_id, :distinguished_name, :group_scope, :group_type, :other_attributes, :realm, :sam_account_name, :sid) SENSITIVE = [:distinguished_name] include Aws::Structure end |
#group_scope ⇒ String
The scope of the AD group. For details, see [Active Directory security groups].
547 548 549 550 551 552 553 554 555 556 557 558 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 547 class DescribeGroupResult < Struct.new( :directory_id, :distinguished_name, :group_scope, :group_type, :other_attributes, :realm, :sam_account_name, :sid) SENSITIVE = [:distinguished_name] include Aws::Structure end |
#group_type ⇒ String
The AD group type. For details, see [Active Directory security group type].
547 548 549 550 551 552 553 554 555 556 557 558 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 547 class DescribeGroupResult < Struct.new( :directory_id, :distinguished_name, :group_scope, :group_type, :other_attributes, :realm, :sam_account_name, :sid) SENSITIVE = [:distinguished_name] include Aws::Structure end |
#other_attributes ⇒ Hash<String,Types::AttributeValue>
The attribute values that are returned for the attribute names that are included in the request.
547 548 549 550 551 552 553 554 555 556 557 558 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 547 class DescribeGroupResult < Struct.new( :directory_id, :distinguished_name, :group_scope, :group_type, :other_attributes, :realm, :sam_account_name, :sid) SENSITIVE = [:distinguished_name] include Aws::Structure end |
#realm ⇒ String
The domain name that’s associated with the group.
547 548 549 550 551 552 553 554 555 556 557 558 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 547 class DescribeGroupResult < Struct.new( :directory_id, :distinguished_name, :group_scope, :group_type, :other_attributes, :realm, :sam_account_name, :sid) SENSITIVE = [:distinguished_name] include Aws::Structure end |
#sam_account_name ⇒ String
The name of the group.
547 548 549 550 551 552 553 554 555 556 557 558 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 547 class DescribeGroupResult < Struct.new( :directory_id, :distinguished_name, :group_scope, :group_type, :other_attributes, :realm, :sam_account_name, :sid) SENSITIVE = [:distinguished_name] include Aws::Structure end |
#sid ⇒ String
The unique security identifier (SID) of the group.
547 548 549 550 551 552 553 554 555 556 557 558 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 547 class DescribeGroupResult < Struct.new( :directory_id, :distinguished_name, :group_scope, :group_type, :other_attributes, :realm, :sam_account_name, :sid) SENSITIVE = [:distinguished_name] include Aws::Structure end |