Class: Aws::DirectoryServiceData::Types::DescribeUserRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-directoryservicedata/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#directory_idString

The identifier (ID) of the directory that’s associated with the user.

Returns:

  • (String)


593
594
595
596
597
598
599
600
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 593

class DescribeUserRequest < Struct.new(
  :directory_id,
  :other_attributes,
  :realm,
  :sam_account_name)
  SENSITIVE = []
  include Aws::Structure
end

#other_attributesArray<String>

One or more attribute names to be returned for the user. A key is an attribute name, and the value is a list of maps. For a list of supported attributes, see [Directory Service Data Attributes].

[1]: docs.aws.amazon.com/directoryservice/latest/admin-guide/ad_data_attributes.html

Returns:

  • (Array<String>)


593
594
595
596
597
598
599
600
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 593

class DescribeUserRequest < Struct.new(
  :directory_id,
  :other_attributes,
  :realm,
  :sam_account_name)
  SENSITIVE = []
  include Aws::Structure
end

#realmString

The domain name that’s associated with the user.

<note markdown=“1”> This parameter is optional, so you can return users outside your Managed Microsoft AD domain. When no value is defined, only your Managed Microsoft AD users are returned.

This value is case insensitive.

</note>

Returns:

  • (String)


593
594
595
596
597
598
599
600
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 593

class DescribeUserRequest < Struct.new(
  :directory_id,
  :other_attributes,
  :realm,
  :sam_account_name)
  SENSITIVE = []
  include Aws::Structure
end

#sam_account_nameString

The name of the user.

Returns:

  • (String)


593
594
595
596
597
598
599
600
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 593

class DescribeUserRequest < Struct.new(
  :directory_id,
  :other_attributes,
  :realm,
  :sam_account_name)
  SENSITIVE = []
  include Aws::Structure
end