Class: Aws::DirectoryServiceData::Types::DescribeUserResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-directoryservicedata/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:distinguished_name, :email_address, :given_name, :surname, :user_principal_name]

Instance Attribute Summary collapse

Instance Attribute Details

#directory_idString

The identifier (ID) of the directory that’s associated with the user.

Returns:

  • (String)


664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 664

class DescribeUserResult < Struct.new(
  :directory_id,
  :distinguished_name,
  :email_address,
  :enabled,
  :given_name,
  :other_attributes,
  :realm,
  :sam_account_name,
  :sid,
  :surname,
  :user_principal_name)
  SENSITIVE = [:distinguished_name, :email_address, :given_name, :surname, :user_principal_name]
  include Aws::Structure
end

#distinguished_nameString

Returns:

  • (String)


664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 664

class DescribeUserResult < Struct.new(
  :directory_id,
  :distinguished_name,
  :email_address,
  :enabled,
  :given_name,
  :other_attributes,
  :realm,
  :sam_account_name,
  :sid,
  :surname,
  :user_principal_name)
  SENSITIVE = [:distinguished_name, :email_address, :given_name, :surname, :user_principal_name]
  include Aws::Structure
end

#email_addressString

The email address of the user.

Returns:

  • (String)


664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 664

class DescribeUserResult < Struct.new(
  :directory_id,
  :distinguished_name,
  :email_address,
  :enabled,
  :given_name,
  :other_attributes,
  :realm,
  :sam_account_name,
  :sid,
  :surname,
  :user_principal_name)
  SENSITIVE = [:distinguished_name, :email_address, :given_name, :surname, :user_principal_name]
  include Aws::Structure
end

#enabledBoolean

Indicates whether the user account is active.

Returns:

  • (Boolean)


664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 664

class DescribeUserResult < Struct.new(
  :directory_id,
  :distinguished_name,
  :email_address,
  :enabled,
  :given_name,
  :other_attributes,
  :realm,
  :sam_account_name,
  :sid,
  :surname,
  :user_principal_name)
  SENSITIVE = [:distinguished_name, :email_address, :given_name, :surname, :user_principal_name]
  include Aws::Structure
end

#given_nameString

The first name of the user.

Returns:

  • (String)


664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 664

class DescribeUserResult < Struct.new(
  :directory_id,
  :distinguished_name,
  :email_address,
  :enabled,
  :given_name,
  :other_attributes,
  :realm,
  :sam_account_name,
  :sid,
  :surname,
  :user_principal_name)
  SENSITIVE = [:distinguished_name, :email_address, :given_name, :surname, :user_principal_name]
  include Aws::Structure
end

#other_attributesHash<String,Types::AttributeValue>

The attribute values that are returned for the attribute names that are included in the request.

<note markdown=“1”> Attribute names are case insensitive.

</note>

Returns:



664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 664

class DescribeUserResult < Struct.new(
  :directory_id,
  :distinguished_name,
  :email_address,
  :enabled,
  :given_name,
  :other_attributes,
  :realm,
  :sam_account_name,
  :sid,
  :surname,
  :user_principal_name)
  SENSITIVE = [:distinguished_name, :email_address, :given_name, :surname, :user_principal_name]
  include Aws::Structure
end

#realmString

The domain name that’s associated with the user.

Returns:

  • (String)


664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 664

class DescribeUserResult < Struct.new(
  :directory_id,
  :distinguished_name,
  :email_address,
  :enabled,
  :given_name,
  :other_attributes,
  :realm,
  :sam_account_name,
  :sid,
  :surname,
  :user_principal_name)
  SENSITIVE = [:distinguished_name, :email_address, :given_name, :surname, :user_principal_name]
  include Aws::Structure
end

#sam_account_nameString

The name of the user.

Returns:

  • (String)


664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 664

class DescribeUserResult < Struct.new(
  :directory_id,
  :distinguished_name,
  :email_address,
  :enabled,
  :given_name,
  :other_attributes,
  :realm,
  :sam_account_name,
  :sid,
  :surname,
  :user_principal_name)
  SENSITIVE = [:distinguished_name, :email_address, :given_name, :surname, :user_principal_name]
  include Aws::Structure
end

#sidString

The unique security identifier (SID) of the user.

Returns:

  • (String)


664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 664

class DescribeUserResult < Struct.new(
  :directory_id,
  :distinguished_name,
  :email_address,
  :enabled,
  :given_name,
  :other_attributes,
  :realm,
  :sam_account_name,
  :sid,
  :surname,
  :user_principal_name)
  SENSITIVE = [:distinguished_name, :email_address, :given_name, :surname, :user_principal_name]
  include Aws::Structure
end

#surnameString

The last name of the user.

Returns:

  • (String)


664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 664

class DescribeUserResult < Struct.new(
  :directory_id,
  :distinguished_name,
  :email_address,
  :enabled,
  :given_name,
  :other_attributes,
  :realm,
  :sam_account_name,
  :sid,
  :surname,
  :user_principal_name)
  SENSITIVE = [:distinguished_name, :email_address, :given_name, :surname, :user_principal_name]
  include Aws::Structure
end

#user_principal_nameString

The UPN that is an Internet-style login name for a user and is based on the Internet standard [RFC 822]. The UPN is shorter than the distinguished name and easier to remember.

[1]: datatracker.ietf.org/doc/html/rfc822

Returns:

  • (String)


664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 664

class DescribeUserResult < Struct.new(
  :directory_id,
  :distinguished_name,
  :email_address,
  :enabled,
  :given_name,
  :other_attributes,
  :realm,
  :sam_account_name,
  :sid,
  :surname,
  :user_principal_name)
  SENSITIVE = [:distinguished_name, :email_address, :given_name, :surname, :user_principal_name]
  include Aws::Structure
end