Class: Aws::DirectoryServiceData::Types::ThrottlingException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-directoryservicedata/types.rb

Overview

The limit on the number of requests per second has been exceeded.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


1454
1455
1456
1457
1458
1459
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 1454

class ThrottlingException < Struct.new(
  :message,
  :retry_after_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#retry_after_secondsInteger

The recommended amount of seconds to retry after a throttling exception.

Returns:

  • (Integer)


1454
1455
1456
1457
1458
1459
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 1454

class ThrottlingException < Struct.new(
  :message,
  :retry_after_seconds)
  SENSITIVE = []
  include Aws::Structure
end