Class: Aws::DirectoryServiceData::Types::UpdateGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-directoryservicedata/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique and case-sensitive identifier that you provide to make sure the idempotency of the request, so multiple identical calls have the same effect as one single call.

A client token is valid for 8 hours after the first request that uses it completes. After 8 hours, any request with the same client token is treated as a new request. If the request succeeds, any future uses of that token will be idempotent for another 8 hours.

If you submit a request with the same client token but change one of the other parameters within the 8-hour idempotency window, Directory Service Data returns an ConflictException.

<note markdown=“1”> This parameter is optional when using the CLI or SDK.

</note>

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 1523

class UpdateGroupRequest < Struct.new(
  :client_token,
  :directory_id,
  :group_scope,
  :group_type,
  :other_attributes,
  :sam_account_name,
  :update_type)
  SENSITIVE = []
  include Aws::Structure
end

#directory_idString

The identifier (ID) of the directory that’s associated with the group.

Returns:

  • (String)


1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 1523

class UpdateGroupRequest < Struct.new(
  :client_token,
  :directory_id,
  :group_scope,
  :group_type,
  :other_attributes,
  :sam_account_name,
  :update_type)
  SENSITIVE = []
  include Aws::Structure
end

#group_scopeString

The scope of the AD group. For details, see [Active Directory security groups].

[1]: learn.microsoft.com/en-us/windows-server/identity/ad-ds/manage/understand-security-groups#group-scope

Returns:

  • (String)


1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 1523

class UpdateGroupRequest < Struct.new(
  :client_token,
  :directory_id,
  :group_scope,
  :group_type,
  :other_attributes,
  :sam_account_name,
  :update_type)
  SENSITIVE = []
  include Aws::Structure
end

#group_typeString

Returns:

  • (String)


1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 1523

class UpdateGroupRequest < Struct.new(
  :client_token,
  :directory_id,
  :group_scope,
  :group_type,
  :other_attributes,
  :sam_account_name,
  :update_type)
  SENSITIVE = []
  include Aws::Structure
end

#other_attributesHash<String,Types::AttributeValue>

An expression that defines one or more attributes with the data type and the value of each attribute.

Returns:



1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 1523

class UpdateGroupRequest < Struct.new(
  :client_token,
  :directory_id,
  :group_scope,
  :group_type,
  :other_attributes,
  :sam_account_name,
  :update_type)
  SENSITIVE = []
  include Aws::Structure
end

#sam_account_nameString

The name of the group.

Returns:

  • (String)


1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 1523

class UpdateGroupRequest < Struct.new(
  :client_token,
  :directory_id,
  :group_scope,
  :group_type,
  :other_attributes,
  :sam_account_name,
  :update_type)
  SENSITIVE = []
  include Aws::Structure
end

#update_typeString

The type of update to be performed. If no value exists for the attribute, use ADD. Otherwise, use REPLACE to change an attribute value or REMOVE to clear the attribute value.

Returns:

  • (String)


1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 1523

class UpdateGroupRequest < Struct.new(
  :client_token,
  :directory_id,
  :group_scope,
  :group_type,
  :other_attributes,
  :sam_account_name,
  :update_type)
  SENSITIVE = []
  include Aws::Structure
end