Class: Aws::DirectoryServiceData::Types::UpdateUserRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-directoryservicedata/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:email_address, :given_name, :surname]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique and case-sensitive identifier that you provide to make sure the idempotency of the request, so multiple identical calls have the same effect as one single call.

A client token is valid for 8 hours after the first request that uses it completes. After 8 hours, any request with the same client token is treated as a new request. If the request succeeds, any future uses of that token will be idempotent for another 8 hours.

If you submit a request with the same client token but change one of the other parameters within the 8-hour idempotency window, Directory Service Data returns an ConflictException.

<note markdown=“1”> This parameter is optional when using the CLI or SDK.

</note>

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 1605

class UpdateUserRequest < Struct.new(
  :client_token,
  :directory_id,
  :email_address,
  :given_name,
  :other_attributes,
  :sam_account_name,
  :surname,
  :update_type)
  SENSITIVE = [:email_address, :given_name, :surname]
  include Aws::Structure
end

#directory_idString

The identifier (ID) of the directory that’s associated with the user.

Returns:

  • (String)


1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 1605

class UpdateUserRequest < Struct.new(
  :client_token,
  :directory_id,
  :email_address,
  :given_name,
  :other_attributes,
  :sam_account_name,
  :surname,
  :update_type)
  SENSITIVE = [:email_address, :given_name, :surname]
  include Aws::Structure
end

#email_addressString

The email address of the user.

Returns:

  • (String)


1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 1605

class UpdateUserRequest < Struct.new(
  :client_token,
  :directory_id,
  :email_address,
  :given_name,
  :other_attributes,
  :sam_account_name,
  :surname,
  :update_type)
  SENSITIVE = [:email_address, :given_name, :surname]
  include Aws::Structure
end

#given_nameString

The first name of the user.

Returns:

  • (String)


1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 1605

class UpdateUserRequest < Struct.new(
  :client_token,
  :directory_id,
  :email_address,
  :given_name,
  :other_attributes,
  :sam_account_name,
  :surname,
  :update_type)
  SENSITIVE = [:email_address, :given_name, :surname]
  include Aws::Structure
end

#other_attributesHash<String,Types::AttributeValue>

An expression that defines one or more attribute names with the data type and value of each attribute. A key is an attribute name, and the value is a list of maps. For a list of supported attributes, see [Directory Service Data Attributes].

<note markdown=“1”> Attribute names are case insensitive.

</note>

[1]: docs.aws.amazon.com/directoryservice/latest/admin-guide/ad_data_attributes.html

Returns:



1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 1605

class UpdateUserRequest < Struct.new(
  :client_token,
  :directory_id,
  :email_address,
  :given_name,
  :other_attributes,
  :sam_account_name,
  :surname,
  :update_type)
  SENSITIVE = [:email_address, :given_name, :surname]
  include Aws::Structure
end

#sam_account_nameString

The name of the user.

Returns:

  • (String)


1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 1605

class UpdateUserRequest < Struct.new(
  :client_token,
  :directory_id,
  :email_address,
  :given_name,
  :other_attributes,
  :sam_account_name,
  :surname,
  :update_type)
  SENSITIVE = [:email_address, :given_name, :surname]
  include Aws::Structure
end

#surnameString

The last name of the user.

Returns:

  • (String)


1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 1605

class UpdateUserRequest < Struct.new(
  :client_token,
  :directory_id,
  :email_address,
  :given_name,
  :other_attributes,
  :sam_account_name,
  :surname,
  :update_type)
  SENSITIVE = [:email_address, :given_name, :surname]
  include Aws::Structure
end

#update_typeString

The type of update to be performed. If no value exists for the attribute, use ADD. Otherwise, use REPLACE to change an attribute value or REMOVE to clear the attribute value.

Returns:

  • (String)


1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 1605

class UpdateUserRequest < Struct.new(
  :client_token,
  :directory_id,
  :email_address,
  :given_name,
  :other_attributes,
  :sam_account_name,
  :surname,
  :update_type)
  SENSITIVE = [:email_address, :given_name, :surname]
  include Aws::Structure
end