Class: Aws::DirectoryServiceData::Types::User
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectoryServiceData::Types::User
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directoryservicedata/types.rb
Overview
A user object that contains identifying information and attributes for a specified user.
Constant Summary collapse
- SENSITIVE =
[:distinguished_name, :email_address, :given_name, :surname, :user_principal_name]
Instance Attribute Summary collapse
-
#distinguished_name ⇒ String
The [distinguished name] of the object.
-
#email_address ⇒ String
The email address of the user.
-
#enabled ⇒ Boolean
Indicates whether the user account is active.
-
#given_name ⇒ String
The first name of the user.
-
#other_attributes ⇒ Hash<String,Types::AttributeValue>
An expression that includes one or more attributes, data types, and values of a user.
-
#sam_account_name ⇒ String
The name of the user.
-
#sid ⇒ String
The unique security identifier (SID) of the user.
-
#surname ⇒ String
The last name of the user.
-
#user_principal_name ⇒ String
The UPN that is an internet-style login name for a user and based on the internet standard [RFC 822].
Instance Attribute Details
#distinguished_name ⇒ String
The [distinguished name] of the object.
[1]: learn.microsoft.com/en-us/windows/win32/ad/object-names-and-identities#distinguished-name
1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 1674 class User < Struct.new( :distinguished_name, :email_address, :enabled, :given_name, :other_attributes, :sam_account_name, :sid, :surname, :user_principal_name) SENSITIVE = [:distinguished_name, :email_address, :given_name, :surname, :user_principal_name] include Aws::Structure end |
#email_address ⇒ String
The email address of the user.
1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 1674 class User < Struct.new( :distinguished_name, :email_address, :enabled, :given_name, :other_attributes, :sam_account_name, :sid, :surname, :user_principal_name) SENSITIVE = [:distinguished_name, :email_address, :given_name, :surname, :user_principal_name] include Aws::Structure end |
#enabled ⇒ Boolean
Indicates whether the user account is active.
1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 1674 class User < Struct.new( :distinguished_name, :email_address, :enabled, :given_name, :other_attributes, :sam_account_name, :sid, :surname, :user_principal_name) SENSITIVE = [:distinguished_name, :email_address, :given_name, :surname, :user_principal_name] include Aws::Structure end |
#given_name ⇒ String
The first name of the user.
1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 1674 class User < Struct.new( :distinguished_name, :email_address, :enabled, :given_name, :other_attributes, :sam_account_name, :sid, :surname, :user_principal_name) SENSITIVE = [:distinguished_name, :email_address, :given_name, :surname, :user_principal_name] include Aws::Structure end |
#other_attributes ⇒ Hash<String,Types::AttributeValue>
An expression that includes one or more attributes, data types, and values of a user.
1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 1674 class User < Struct.new( :distinguished_name, :email_address, :enabled, :given_name, :other_attributes, :sam_account_name, :sid, :surname, :user_principal_name) SENSITIVE = [:distinguished_name, :email_address, :given_name, :surname, :user_principal_name] include Aws::Structure end |
#sam_account_name ⇒ String
The name of the user.
1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 1674 class User < Struct.new( :distinguished_name, :email_address, :enabled, :given_name, :other_attributes, :sam_account_name, :sid, :surname, :user_principal_name) SENSITIVE = [:distinguished_name, :email_address, :given_name, :surname, :user_principal_name] include Aws::Structure end |
#sid ⇒ String
The unique security identifier (SID) of the user.
1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 1674 class User < Struct.new( :distinguished_name, :email_address, :enabled, :given_name, :other_attributes, :sam_account_name, :sid, :surname, :user_principal_name) SENSITIVE = [:distinguished_name, :email_address, :given_name, :surname, :user_principal_name] include Aws::Structure end |
#surname ⇒ String
The last name of the user.
1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 1674 class User < Struct.new( :distinguished_name, :email_address, :enabled, :given_name, :other_attributes, :sam_account_name, :sid, :surname, :user_principal_name) SENSITIVE = [:distinguished_name, :email_address, :given_name, :surname, :user_principal_name] include Aws::Structure end |
#user_principal_name ⇒ String
The UPN that is an internet-style login name for a user and based on the internet standard [RFC 822]. The UPN is shorter than the distinguished name and easier to remember.
1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 1674 class User < Struct.new( :distinguished_name, :email_address, :enabled, :given_name, :other_attributes, :sam_account_name, :sid, :surname, :user_principal_name) SENSITIVE = [:distinguished_name, :email_address, :given_name, :surname, :user_principal_name] include Aws::Structure end |