Class: Aws::DirectoryServiceData::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::DirectoryServiceData::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-directoryservicedata/client.rb
Overview
An API client for DirectoryServiceData. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::DirectoryServiceData::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#add_group_member(params = {}) ⇒ Struct
Adds an existing user, group, or computer as a group member.
-
#create_group(params = {}) ⇒ Types::CreateGroupResult
Creates a new group.
-
#create_user(params = {}) ⇒ Types::CreateUserResult
Creates a new user.
-
#delete_group(params = {}) ⇒ Struct
Deletes a group.
-
#delete_user(params = {}) ⇒ Struct
Deletes a user.
-
#describe_group(params = {}) ⇒ Types::DescribeGroupResult
Returns information about a specific group.
-
#describe_user(params = {}) ⇒ Types::DescribeUserResult
Returns information about a specific user.
-
#disable_user(params = {}) ⇒ Struct
Deactivates an active user account.
-
#list_group_members(params = {}) ⇒ Types::ListGroupMembersResult
Returns member information for the specified group.
-
#list_groups(params = {}) ⇒ Types::ListGroupsResult
Returns group information for the specified directory.
-
#list_groups_for_member(params = {}) ⇒ Types::ListGroupsForMemberResult
Returns group information for the specified member.
-
#list_users(params = {}) ⇒ Types::ListUsersResult
Returns user information for the specified directory.
-
#remove_group_member(params = {}) ⇒ Struct
Removes a member from a group.
-
#search_groups(params = {}) ⇒ Types::SearchGroupsResult
Searches the specified directory for a group.
-
#search_users(params = {}) ⇒ Types::SearchUsersResult
Searches the specified directory for a user.
-
#update_group(params = {}) ⇒ Struct
Updates group information.
-
#update_user(params = {}) ⇒ Struct
Updates user information.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-directoryservicedata/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1778 1779 1780 |
# File 'lib/aws-sdk-directoryservicedata/client.rb', line 1778 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1781 1782 1783 |
# File 'lib/aws-sdk-directoryservicedata/client.rb', line 1781 def errors_module Errors end |
Instance Method Details
#add_group_member(params = {}) ⇒ Struct
Adds an existing user, group, or computer as a group member.
538 539 540 541 |
# File 'lib/aws-sdk-directoryservicedata/client.rb', line 538 def add_group_member(params = {}, = {}) req = build_request(:add_group_member, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 |
# File 'lib/aws-sdk-directoryservicedata/client.rb', line 1751 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::DirectoryServiceData') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-directoryservicedata' context[:gem_version] = '1.25.0' Seahorse::Client::Request.new(handlers, context) end |
#create_group(params = {}) ⇒ Types::CreateGroupResult
Creates a new group.
622 623 624 625 |
# File 'lib/aws-sdk-directoryservicedata/client.rb', line 622 def create_group(params = {}, = {}) req = build_request(:create_group, params) req.send_request() end |
#create_user(params = {}) ⇒ Types::CreateUserResult
Creates a new user.
709 710 711 712 |
# File 'lib/aws-sdk-directoryservicedata/client.rb', line 709 def create_user(params = {}, = {}) req = build_request(:create_user, params) req.send_request() end |
#delete_group(params = {}) ⇒ Struct
Deletes a group.
758 759 760 761 |
# File 'lib/aws-sdk-directoryservicedata/client.rb', line 758 def delete_group(params = {}, = {}) req = build_request(:delete_group, params) req.send_request() end |
#delete_user(params = {}) ⇒ Struct
Deletes a user.
806 807 808 809 |
# File 'lib/aws-sdk-directoryservicedata/client.rb', line 806 def delete_user(params = {}, = {}) req = build_request(:delete_user, params) req.send_request() end |
#describe_group(params = {}) ⇒ Types::DescribeGroupResult
Returns information about a specific group.
874 875 876 877 |
# File 'lib/aws-sdk-directoryservicedata/client.rb', line 874 def describe_group(params = {}, = {}) req = build_request(:describe_group, params) req.send_request() end |
#describe_user(params = {}) ⇒ Types::DescribeUserResult
Returns information about a specific user.
949 950 951 952 |
# File 'lib/aws-sdk-directoryservicedata/client.rb', line 949 def describe_user(params = {}, = {}) req = build_request(:describe_user, params) req.send_request() end |
#disable_user(params = {}) ⇒ Struct
Deactivates an active user account. For information about how to enable an inactive user account, see [ResetUserPassword] in the *Directory Service API Reference*.
[1]: docs.aws.amazon.com/directoryservice/latest/devguide/API_ResetUserPassword.html
1003 1004 1005 1006 |
# File 'lib/aws-sdk-directoryservicedata/client.rb', line 1003 def disable_user(params = {}, = {}) req = build_request(:disable_user, params) req.send_request() end |
#list_group_members(params = {}) ⇒ Types::ListGroupMembersResult
Returns member information for the specified group.
This operation supports pagination with the use of the ‘NextToken` request and response parameters. If more results are available, the `ListGroupMembers.NextToken` member contains a token that you pass in the next call to `ListGroupMembers`. This retrieves the next set of items.
You can also specify a maximum number of return results with the ‘MaxResults` parameter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1088 1089 1090 1091 |
# File 'lib/aws-sdk-directoryservicedata/client.rb', line 1088 def list_group_members(params = {}, = {}) req = build_request(:list_group_members, params) req.send_request() end |
#list_groups(params = {}) ⇒ Types::ListGroupsResult
Returns group information for the specified directory.
This operation supports pagination with the use of the ‘NextToken` request and response parameters. If more results are available, the `ListGroups.NextToken` member contains a token that you pass in the next call to `ListGroups`. This retrieves the next set of items.
You can also specify a maximum number of return results with the ‘MaxResults` parameter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1158 1159 1160 1161 |
# File 'lib/aws-sdk-directoryservicedata/client.rb', line 1158 def list_groups(params = {}, = {}) req = build_request(:list_groups, params) req.send_request() end |
#list_groups_for_member(params = {}) ⇒ Types::ListGroupsForMemberResult
Returns group information for the specified member.
This operation supports pagination with the use of the ‘NextToken` request and response parameters. If more results are available, the `ListGroupsForMember.NextToken` member contains a token that you pass in the next call to `ListGroupsForMember`. This retrieves the next set of items.
You can also specify a maximum number of return results with the ‘MaxResults` parameter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1248 1249 1250 1251 |
# File 'lib/aws-sdk-directoryservicedata/client.rb', line 1248 def list_groups_for_member(params = {}, = {}) req = build_request(:list_groups_for_member, params) req.send_request() end |
#list_users(params = {}) ⇒ Types::ListUsersResult
Returns user information for the specified directory.
This operation supports pagination with the use of the ‘NextToken` request and response parameters. If more results are available, the `ListUsers.NextToken` member contains a token that you pass in the next call to `ListUsers`. This retrieves the next set of items.
You can also specify a maximum number of return results with the ‘MaxResults` parameter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1318 1319 1320 1321 |
# File 'lib/aws-sdk-directoryservicedata/client.rb', line 1318 def list_users(params = {}, = {}) req = build_request(:list_users, params) req.send_request() end |
#remove_group_member(params = {}) ⇒ Struct
Removes a member from a group.
1381 1382 1383 1384 |
# File 'lib/aws-sdk-directoryservicedata/client.rb', line 1381 def remove_group_member(params = {}, = {}) req = build_request(:remove_group_member, params) req.send_request() end |
#search_groups(params = {}) ⇒ Types::SearchGroupsResult
Searches the specified directory for a group. You can find groups that match the ‘SearchString` parameter with the value of their attributes included in the `SearchString` parameter.
This operation supports pagination with the use of the ‘NextToken` request and response parameters. If more results are available, the `SearchGroups.NextToken` member contains a token that you pass in the next call to `SearchGroups`. This retrieves the next set of items.
You can also specify a maximum number of return results with the ‘MaxResults` parameter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1479 1480 1481 1482 |
# File 'lib/aws-sdk-directoryservicedata/client.rb', line 1479 def search_groups(params = {}, = {}) req = build_request(:search_groups, params) req.send_request() end |
#search_users(params = {}) ⇒ Types::SearchUsersResult
Searches the specified directory for a user. You can find users that match the ‘SearchString` parameter with the value of their attributes included in the `SearchString` parameter.
This operation supports pagination with the use of the ‘NextToken` request and response parameters. If more results are available, the `SearchUsers.NextToken` member contains a token that you pass in the next call to `SearchUsers`. This retrieves the next set of items.
You can also specify a maximum number of return results with the ‘MaxResults` parameter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1579 1580 1581 1582 |
# File 'lib/aws-sdk-directoryservicedata/client.rb', line 1579 def search_users(params = {}, = {}) req = build_request(:search_users, params) req.send_request() end |
#update_group(params = {}) ⇒ Struct
Updates group information.
1659 1660 1661 1662 |
# File 'lib/aws-sdk-directoryservicedata/client.rb', line 1659 def update_group(params = {}, = {}) req = build_request(:update_group, params) req.send_request() end |
#update_user(params = {}) ⇒ Struct
Updates user information.
1742 1743 1744 1745 |
# File 'lib/aws-sdk-directoryservicedata/client.rb', line 1742 def update_user(params = {}, = {}) req = build_request(:update_user, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1771 1772 1773 |
# File 'lib/aws-sdk-directoryservicedata/client.rb', line 1771 def waiter_names [] end |