Class: Aws::DirectoryServiceData::Types::ConflictException
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectoryServiceData::Types::ConflictException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directoryservicedata/types.rb
Overview
This error will occur when you try to create a resource that conflicts with an existing object. It can also occur when adding a member to a group that the member is already in.
This error can be caused by a request sent within the 8-hour idempotency window with the same client token but different input parameters. Client tokens should not be re-used across different requests. After 8 hours, any request with the same client token is treated as a new request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
176 177 178 179 180 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 176 class ConflictException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |