Class: Aws::DirectoryServiceData::Types::DescribeUserResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectoryServiceData::Types::DescribeUserResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directoryservicedata/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:distinguished_name, :email_address, :given_name, :surname, :user_principal_name]
Instance Attribute Summary collapse
-
#directory_id ⇒ String
The identifier (ID) of the directory that’s associated with the user.
-
#distinguished_name ⇒ String
The [distinguished name] of the object.
-
#email_address ⇒ String
The email address of the user.
-
#enabled ⇒ Boolean
Indicates whether the user account is active.
-
#given_name ⇒ String
The first name of the user.
-
#other_attributes ⇒ Hash<String,Types::AttributeValue>
The attribute values that are returned for the attribute names that are included in the request.
-
#realm ⇒ String
The domain name that’s associated with the user.
-
#sam_account_name ⇒ String
The name of the user.
-
#sid ⇒ String
The unique security identifier (SID) of the user.
-
#surname ⇒ String
The last name of the user.
-
#user_principal_name ⇒ String
The UPN that is an Internet-style login name for a user and is based on the Internet standard [RFC 822].
Instance Attribute Details
#directory_id ⇒ String
The identifier (ID) of the directory that’s associated with the user.
664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 664 class DescribeUserResult < Struct.new( :directory_id, :distinguished_name, :email_address, :enabled, :given_name, :other_attributes, :realm, :sam_account_name, :sid, :surname, :user_principal_name) SENSITIVE = [:distinguished_name, :email_address, :given_name, :surname, :user_principal_name] include Aws::Structure end |
#distinguished_name ⇒ String
The [distinguished name] of the object.
[1]: learn.microsoft.com/en-us/windows/win32/ad/object-names-and-identities#distinguished-name
664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 664 class DescribeUserResult < Struct.new( :directory_id, :distinguished_name, :email_address, :enabled, :given_name, :other_attributes, :realm, :sam_account_name, :sid, :surname, :user_principal_name) SENSITIVE = [:distinguished_name, :email_address, :given_name, :surname, :user_principal_name] include Aws::Structure end |
#email_address ⇒ String
The email address of the user.
664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 664 class DescribeUserResult < Struct.new( :directory_id, :distinguished_name, :email_address, :enabled, :given_name, :other_attributes, :realm, :sam_account_name, :sid, :surname, :user_principal_name) SENSITIVE = [:distinguished_name, :email_address, :given_name, :surname, :user_principal_name] include Aws::Structure end |
#enabled ⇒ Boolean
Indicates whether the user account is active.
664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 664 class DescribeUserResult < Struct.new( :directory_id, :distinguished_name, :email_address, :enabled, :given_name, :other_attributes, :realm, :sam_account_name, :sid, :surname, :user_principal_name) SENSITIVE = [:distinguished_name, :email_address, :given_name, :surname, :user_principal_name] include Aws::Structure end |
#given_name ⇒ String
The first name of the user.
664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 664 class DescribeUserResult < Struct.new( :directory_id, :distinguished_name, :email_address, :enabled, :given_name, :other_attributes, :realm, :sam_account_name, :sid, :surname, :user_principal_name) SENSITIVE = [:distinguished_name, :email_address, :given_name, :surname, :user_principal_name] include Aws::Structure end |
#other_attributes ⇒ Hash<String,Types::AttributeValue>
The attribute values that are returned for the attribute names that are included in the request.
<note markdown=“1”> Attribute names are case insensitive.
</note>
664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 664 class DescribeUserResult < Struct.new( :directory_id, :distinguished_name, :email_address, :enabled, :given_name, :other_attributes, :realm, :sam_account_name, :sid, :surname, :user_principal_name) SENSITIVE = [:distinguished_name, :email_address, :given_name, :surname, :user_principal_name] include Aws::Structure end |
#realm ⇒ String
The domain name that’s associated with the user.
664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 664 class DescribeUserResult < Struct.new( :directory_id, :distinguished_name, :email_address, :enabled, :given_name, :other_attributes, :realm, :sam_account_name, :sid, :surname, :user_principal_name) SENSITIVE = [:distinguished_name, :email_address, :given_name, :surname, :user_principal_name] include Aws::Structure end |
#sam_account_name ⇒ String
The name of the user.
664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 664 class DescribeUserResult < Struct.new( :directory_id, :distinguished_name, :email_address, :enabled, :given_name, :other_attributes, :realm, :sam_account_name, :sid, :surname, :user_principal_name) SENSITIVE = [:distinguished_name, :email_address, :given_name, :surname, :user_principal_name] include Aws::Structure end |
#sid ⇒ String
The unique security identifier (SID) of the user.
664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 664 class DescribeUserResult < Struct.new( :directory_id, :distinguished_name, :email_address, :enabled, :given_name, :other_attributes, :realm, :sam_account_name, :sid, :surname, :user_principal_name) SENSITIVE = [:distinguished_name, :email_address, :given_name, :surname, :user_principal_name] include Aws::Structure end |
#surname ⇒ String
The last name of the user.
664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 664 class DescribeUserResult < Struct.new( :directory_id, :distinguished_name, :email_address, :enabled, :given_name, :other_attributes, :realm, :sam_account_name, :sid, :surname, :user_principal_name) SENSITIVE = [:distinguished_name, :email_address, :given_name, :surname, :user_principal_name] include Aws::Structure end |
#user_principal_name ⇒ String
The UPN that is an Internet-style login name for a user and is based on the Internet standard [RFC 822]. The UPN is shorter than the distinguished name and easier to remember.
664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 664 class DescribeUserResult < Struct.new( :directory_id, :distinguished_name, :email_address, :enabled, :given_name, :other_attributes, :realm, :sam_account_name, :sid, :surname, :user_principal_name) SENSITIVE = [:distinguished_name, :email_address, :given_name, :surname, :user_principal_name] include Aws::Structure end |