Class: Aws::DirectoryServiceData::Types::RemoveGroupMemberRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectoryServiceData::Types::RemoveGroupMemberRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directoryservicedata/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique and case-sensitive identifier that you provide to make sure the idempotency of the request, so multiple identical calls have the same effect as one single call.
-
#directory_id ⇒ String
The identifier (ID) of the directory that’s associated with the member.
-
#group_name ⇒ String
The name of the group.
-
#member_name ⇒ String
The
SAMAccountNameof the user, group, or computer to remove from the group. -
#member_realm ⇒ String
The domain name that’s associated with the group member.
Instance Attribute Details
#client_token ⇒ String
A unique and case-sensitive identifier that you provide to make sure the idempotency of the request, so multiple identical calls have the same effect as one single call.
A client token is valid for 8 hours after the first request that uses it completes. After 8 hours, any request with the same client token is treated as a new request. If the request succeeds, any future uses of that token will be idempotent for another 8 hours.
If you submit a request with the same client token but change one of the other parameters within the 8-hour idempotency window, Directory Service Data returns an ConflictException.
<note markdown=“1”> This parameter is optional when using the CLI or SDK.
</note>
**A suitable default value is auto-generated.** You should normally not need to pass this option.
1233 1234 1235 1236 1237 1238 1239 1240 1241 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 1233 class RemoveGroupMemberRequest < Struct.new( :client_token, :directory_id, :group_name, :member_name, :member_realm) SENSITIVE = [] include Aws::Structure end |
#directory_id ⇒ String
The identifier (ID) of the directory that’s associated with the member.
1233 1234 1235 1236 1237 1238 1239 1240 1241 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 1233 class RemoveGroupMemberRequest < Struct.new( :client_token, :directory_id, :group_name, :member_name, :member_realm) SENSITIVE = [] include Aws::Structure end |
#group_name ⇒ String
The name of the group.
1233 1234 1235 1236 1237 1238 1239 1240 1241 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 1233 class RemoveGroupMemberRequest < Struct.new( :client_token, :directory_id, :group_name, :member_name, :member_realm) SENSITIVE = [] include Aws::Structure end |
#member_name ⇒ String
The SAMAccountName of the user, group, or computer to remove from the group.
1233 1234 1235 1236 1237 1238 1239 1240 1241 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 1233 class RemoveGroupMemberRequest < Struct.new( :client_token, :directory_id, :group_name, :member_name, :member_realm) SENSITIVE = [] include Aws::Structure end |
#member_realm ⇒ String
The domain name that’s associated with the group member. This parameter defaults to the Managed Microsoft AD domain.
<note markdown=“1”> This parameter is optional and case insensitive.
</note>
1233 1234 1235 1236 1237 1238 1239 1240 1241 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 1233 class RemoveGroupMemberRequest < Struct.new( :client_token, :directory_id, :group_name, :member_name, :member_realm) SENSITIVE = [] include Aws::Structure end |