Class: Aws::DirectoryServiceData::Types::SearchGroupsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectoryServiceData::Types::SearchGroupsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directoryservicedata/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:next_token, :search_string]
Instance Attribute Summary collapse
-
#directory_id ⇒ String
The identifier (ID) of the directory that’s associated with the group.
-
#max_results ⇒ Integer
The maximum number of results to be returned per request.
-
#next_token ⇒ String
An encoded paging token for paginated calls that can be passed back to retrieve the next page.
-
#realm ⇒ String
The domain name that’s associated with the group.
-
#search_attributes ⇒ Array<String>
One or more data attributes that are used to search for a group.
-
#search_string ⇒ String
The attribute value that you want to search for.
Instance Attribute Details
#directory_id ⇒ String
The identifier (ID) of the directory that’s associated with the group.
1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 1311 class SearchGroupsRequest < Struct.new( :directory_id, :max_results, :next_token, :realm, :search_attributes, :search_string) SENSITIVE = [:next_token, :search_string] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to be returned per request.
1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 1311 class SearchGroupsRequest < Struct.new( :directory_id, :max_results, :next_token, :realm, :search_attributes, :search_string) SENSITIVE = [:next_token, :search_string] include Aws::Structure end |
#next_token ⇒ String
An encoded paging token for paginated calls that can be passed back to retrieve the next page.
1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 1311 class SearchGroupsRequest < Struct.new( :directory_id, :max_results, :next_token, :realm, :search_attributes, :search_string) SENSITIVE = [:next_token, :search_string] include Aws::Structure end |
#realm ⇒ String
The domain name that’s associated with the group.
<note markdown=“1”> This parameter is optional, so you can return groups outside of your Managed Microsoft AD domain. When no value is defined, only your Managed Microsoft AD groups are returned.
This value is case insensitive.
</note>
1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 1311 class SearchGroupsRequest < Struct.new( :directory_id, :max_results, :next_token, :realm, :search_attributes, :search_string) SENSITIVE = [:next_token, :search_string] include Aws::Structure end |
#search_attributes ⇒ Array<String>
One or more data attributes that are used to search for a group. For a list of supported attributes, see [Directory Service Data Attributes].
[1]: docs.aws.amazon.com/directoryservice/latest/admin-guide/ad_data_attributes.html
1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 1311 class SearchGroupsRequest < Struct.new( :directory_id, :max_results, :next_token, :realm, :search_attributes, :search_string) SENSITIVE = [:next_token, :search_string] include Aws::Structure end |
#search_string ⇒ String
The attribute value that you want to search for.
<note markdown=“1”> Wildcard ‘(*)` searches aren’t supported. For a list of supported attributes, see [Directory Service Data Attributes].
</note>
[1]: docs.aws.amazon.com/directoryservice/latest/admin-guide/ad_data_attributes.html
1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 |
# File 'lib/aws-sdk-directoryservicedata/types.rb', line 1311 class SearchGroupsRequest < Struct.new( :directory_id, :max_results, :next_token, :realm, :search_attributes, :search_string) SENSITIVE = [:next_token, :search_string] include Aws::Structure end |